#include <stdio.h>
#include <sybfront.h>
#include <sybdb.h>
#include "sybdbex.h"
#include <wiscbench.h>

/*
 * wisc_index.c
 *
 * Wisconsin Benchmark - Create indexes for wisconsin benchmark tables
 *
 *      unique2 - clustered
 *      unique1 - non-clustered
 *      onePercent - non-clustered
 *
*/

main (argc,argv)
    char	**argv;

{
    /* sybase specific variables */
    DBPROCESS       *dbproc;
    RETCODE        result_code; /* to hold the results of dbresults(). */
    STATUS         row_code;    /* to hold the results of dbnextrow(). */

    char	*username;
    char	*passwd;
    char	*optstring;
    extern 	char *optarg;
    extern 	int optind, opterr;
    int		c;
    int		errflg;

    char	query[1000];

    username = passwd = NULL;
    errflg = 0;
    /* process the command line arguments */
    while ((c = getopt(argc,argv,"u:p:")) != EOF)
    {
	switch (c) {
	case 'u':	// get user name
	    username = optarg; 
	    break;
	case 'p':	// get user passwd
	    passwd = optarg;
	    break;
	case '?':
	    errflg++;
	}
	if (errflg) 
	{
	     usage();
	     exit (2);
	}
    }

    /* next open the database */
    dbproc = open_db(DATABASE, username, passwd,FALSE);

    /* create indices*/

    printf("Creating clustered index on %s(unique2D)\n",BASERELATION1); 
    sprintf(query, 
     "create unique clustered index %s_2D on %s (unique2D) with fillfactor=95",
      BASERELATION1, BASERELATION1);
    dbcmd(dbproc,query); /* form the query */
    dbsqlexec(dbproc);
    while ((result_code = dbresults(dbproc)) != NO_MORE_RESULTS) continue;;


    printf("Creating clustered index on %s(unique2E)\n",BASERELATION2); 
    sprintf(query, 
     "create unique clustered index %s_2E on %s (unique2E) with fillfactor=95",
      BASERELATION2, BASERELATION2);
    dbcmd(dbproc,query); /* form the query */
    dbsqlexec(dbproc);
    while ((result_code = dbresults(dbproc)) != NO_MORE_RESULTS) continue;;

    printf("Creating non-clustered index on %s(unique1D)\n",BASERELATION1); 
    sprintf(query, 
     "create unique nonclustered index %s_1D on %s (unique1D) with fillfactor=95",
      BASERELATION1, BASERELATION1);
    dbcmd(dbproc,query); /* form the query */
    dbsqlexec(dbproc);
    while ((result_code = dbresults(dbproc)) != NO_MORE_RESULTS) continue;;

    printf("Creating non-clustered index on %s(unique1E)\n",BASERELATION2); 
    sprintf(query, 
     "create unique nonclustered index %s_1E on %s (unique1E) with fillfactor=95",
      BASERELATION2, BASERELATION2);
    dbcmd(dbproc,query); /* form the query */
    dbsqlexec(dbproc);
    while ((result_code = dbresults(dbproc)) != NO_MORE_RESULTS) continue;;

    printf("Creating non-clustered index on %s(onePercentD)\n",BASERELATION1); 
    sprintf(query, 
     "create nonclustered index %s_onePerD on %s (onePercentD) with fillfactor=95",
      BASERELATION1, BASERELATION1);
    dbcmd(dbproc,query); /* form the query */
    dbsqlexec(dbproc);
    while ((result_code = dbresults(dbproc)) != NO_MORE_RESULTS) continue;;

    printf("Creating non-cluster index on %s(onePercentE)\n",BASERELATION2); 
    sprintf(query, 
     "create nonclustered index %s_onePerE on %s (onePercentE) with fillfactor=95",
      BASERELATION2, BASERELATION2);
    dbcmd(dbproc,query); /* form the query */
    dbsqlexec(dbproc);
    while ((result_code = dbresults(dbproc)) != NO_MORE_RESULTS) continue;;

    closedb(dbproc);
    exit(STDEXIT);
}

/* =================================================================== */

usage ()
{
    fprintf (stderr,"\nUsage: wisc_index  -u username -p passwd\n");
    exit (1);
}
