#include <stdio.h>
#include <sybfront.h>
#include <sybdb.h>
#include "sybdbex.h"
#include <wiscbench.h>

/*
 * wisc_query19.c
 *
 * Wisconsin Benchmark - Query 19: 100% Projection
 *
 * Implemented by David DeWitt and Michael Franklin
 * 
 * Copyright (c) 1991 David DeWitt and Michael Franklin
 *
 */

main (argc,argv)
    char	**argv;

{
    /* sybase specific variables */
    DBPROCESS       *dbproc;
    RETCODE        result_code; /* to hold the results of dbresults(). */
    STATUS         row_code;    /* to hold the results of dbnextrow(). */

    char	*username;
    char	*passwd;
    char	*optstring;
    extern 	char *optarg;
    extern 	int optind, opterr;
    int		c;
    int		errflg;
    int		no_index;

    int		i;
    int		tupCount; /* number of tuples in the relation */

    char	query[1000];
    int 	starttime, endtime, totaltime;
    int 	numtrials,totalrows,trialrows;

    username = passwd = NULL;
    errflg = 0;
    /* process the command line arguments */
    while ((c = getopt(argc,argv,"u:p:")) != EOF)
    {
	switch (c) {
	case 'u':	// get user name
	    username = optarg; 
	    break;
	case 'p':	// get user passwd
	    passwd = optarg;
	    break;
	case '?':
	    errflg++;
	}
	if (errflg) 
	{
	     usage();
	     exit (2);
	}
    }
    fprintf(stderr,"Query 19: (100%% Project)...\n");

    /* next open the database */
    dbproc = open_db(DATABASE, username, passwd,FALSE);

    /* run query 19 - l00% Projection*/

    /* set base constants */
    tupCount = BASERELSIZE; /* from wiscbench.h */

    numtrials = 0;
    totaltime = 0;
    totalrows = 0;

    for (i=0;i<PROJREPEATCNT/2;i++)
    {
	/* run SELREPEATCNT queries two at a time */

	/* first do one relation */
	create_proj100_temp(dbproc, 1); /* create the result relation */

	sprintf(query,"insert into TMP select distinct twoD, fourD, tenD, twentyD, onePercentD, tenPercentD, twentyPercentD, fiftyPercentD, unique3D, evenOnePercentD, oddOnePercentD, stringu1D, stringu2D, string4D from %s", 
	BASERELATION1);

	if (VERBOSE) printf("next query is: %s\n",query);

	dbcmd(dbproc,query); /* form the query */

        /* Send the command buffer to SQL Server for execution. */
	starttime = time1000();
	dbsqlexec(dbproc);
        while ((result_code = dbresults(dbproc)) != NO_MORE_RESULTS) continue;
    	endtime = time1000();

	/* update running statistics */
    	totaltime += (endtime-starttime);
    	trialrows = get_row_count(dbproc);
    	totalrows += trialrows;
    	drop_table(dbproc, "TMP"); /* delete the result relation */
    	print_trial(++numtrials,trialrows,(endtime-starttime)); 

	/* then do the second relation */
	create_proj100_temp(dbproc, 2); /* create the result relation */

	sprintf(query,"insert into TMP select distinct twoE, fourE, tenE, twentyE, onePercentE, tenPercentE, twentyPercentE, fiftyPercentE, unique3E, evenOnePercentE, oddOnePercentE, stringu1E, stringu2E, string4E from %s", 
	BASERELATION2);

	if (VERBOSE) printf("next query is: %s\n",query);
	dbcmd(dbproc,query); /* form the query */

    	/* Send the command buffer to SQL Server for execution. */
    	starttime = time1000();
    	dbsqlexec(dbproc);
    	while ((result_code = dbresults(dbproc)) != NO_MORE_RESULTS) continue;;
    	endtime = time1000();

	/* update running statistics */
    	totaltime += (endtime-starttime);
    	trialrows = get_row_count(dbproc);
    	totalrows += trialrows;
    	drop_table(dbproc, "TMP"); /* delete the result relation */
    	print_trial(++numtrials,trialrows,(endtime-starttime)); 
    }

    print_result("Query 19 (100% Project)",numtrials, totalrows, totaltime);

    closedb(dbproc);
    exit(STDEXIT);
}

/* =================================================================== */

usage ()
{
    fprintf (stderr,"\nUsage: wisc_query19  -u username -p passwd\n");
    fprintf (stderr,"\t-p: Show query plan\n");
    exit (1);
}
